The project is run on Github, in the [typical](http://producingoss.com) free software way - we'd love to accept your patches and contributions to this project. There is just one thing you need to do first.

Contributions to Google projects, even unofficial ones like this, must be accompanied by a Contributor License Agreement. This is not a copyright assignment, it simply gives Google permission to use and redistribute your contributions as part of the project.

If you are an individual writing original source code and you're sure you own the rights, then you'll need to sign an
[individual CLA](https://developers.google.com/open-source/cla/individual).

If you work for a company that wants to allow you to contribute your work, then you'll need to sign a [corporate CLA](https://developers.google.com/open-source/cla/corporate).

You generally only need to submit a CLA once, so if you've already submitted one for a different project, you probably don't need to do it again.

After your contribution is included, you will be listed in CONTRIBUTORS.txt and/or AUTHORS.txt: CONTRIBUTORS is the official list of people who can contribute (and typically have contributed) code to this repository, while the AUTHORS file lists the copyright holders.
